@@ -268,9 +268,9 @@ class PVDataSource(ImageDataSource):
         pv["x_coords"] = x_coords
         pv["y_coords"] = y_coords
 
-        # pad out so that there are always 32 gsp
+        # pad out so that there are always 32 gsp, pad with zeros
         pad_n = self.n_pv_systems_per_example - len(pv.id_index)
-        pv = pv.pad(id_index=(0, pad_n), data=((0, 0), (0, pad_n)))
+        pv = pv.pad(id_index=(0, pad_n), data=((0, 0), (0, pad_n)), constant_values=0)
 
         pv.__setitem__("id_index", range(self.n_pv_systems_per_example))
 
